pub struct DynamicConfig {
pg_connection_pool_max_size: AtomicUsize,
pg_connection_pool_max_wait: RwLock<Option<Duration>>,
pg_connection_pool_ttl: RwLock<Duration>,
pg_connection_pool_ttl_stagger: RwLock<Duration>,
pg_connection_pool_connect_timeout: RwLock<Duration>,
pg_connection_pool_tcp_user_timeout: RwLock<Duration>,
pg_connection_pool_keepalives_idle: RwLock<Duration>,
pg_connection_pool_keepalives_interval: RwLock<Duration>,
pg_connection_pool_keepalives_retries: AtomicU32,
pg_statement_timeout: RwLock<Duration>,
}Expand description
Part of PostgresTimestampOracleConfig that can be dynamically updated.
The timestamp oracle is expected to react to each of these such that updating the value returned by the function takes effect (i.e. no caching it). This should happen “as promptly as reasonably possible” where that’s defined by the tradeoffs of complexity vs promptness.
These are hooked up to LaunchDarkly. Specifically, LaunchDarkly configs are
serialized into a TimestampOracleParameters. In environmentd,
these are applied directly via TimestampOracleParameters::apply
to the PostgresTimestampOracleConfig.
Fields
pg_connection_pool_max_size: AtomicUsizeThe maximum size of the connection pool to Postgres/CRDB.
pg_connection_pool_max_wait: RwLock<Option<Duration>>The maximum time to wait when attempting to obtain a connection from the pool.
pg_connection_pool_ttl: RwLock<Duration>The minimum TTL of a connection to Postgres/CRDB before it is proactively terminated. Connections are routinely culled to balance load against the downstream database.
pg_connection_pool_ttl_stagger: RwLock<Duration>The minimum time between TTLing connections to Postgres/CRDB. This delay
is used to stagger reconnections to avoid stampedes and high tail
latencies. This value should be much less than connection_pool_ttl so
that reconnections are biased towards terminating the oldest connections
first. A value of connection_pool_ttl / connection_pool_max_size is
likely a good place to start so that all connections are rotated when
the pool is fully used.
pg_connection_pool_connect_timeout: RwLock<Duration>The duration to wait for a Postgres/CRDB connection to be made before retrying.
pg_connection_pool_tcp_user_timeout: RwLock<Duration>The TCP user timeout for a Postgres/CRDB connection. Specifies the amount of time that transmitted data may remain unacknowledged before the TCP connection is forcibly closed.
pg_connection_pool_keepalives_idle: RwLock<Duration>The amount of idle time before a TCP keepalive packet is sent on Postgres/CRDB connections.
pg_connection_pool_keepalives_interval: RwLock<Duration>The time interval between TCP keepalive probes on Postgres/CRDB connections.
pg_connection_pool_keepalives_retries: AtomicU32The maximum number of TCP keepalive probes that will be sent before dropping a Postgres/CRDB connection.
pg_statement_timeout: RwLock<Duration>The server-side statement_timeout to set on each Postgres/CRDB
connection. A zero value is a sentinel that means “do not set a
statement timeout”.
Implementations
Sourceimpl DynamicConfig
impl DynamicConfig
const LOAD_ORDERING: Ordering = Ordering::SeqCst
const STORE_ORDERING: Ordering = Ordering::SeqCst
fn connection_pool_max_size(&self) -> usize
fn connection_pool_max_wait(&self) -> Option<Duration>
fn connection_pool_ttl(&self) -> Duration
fn connection_pool_ttl_stagger(&self) -> Duration
fn connect_timeout(&self) -> Duration
fn tcp_user_timeout(&self) -> Duration
fn keepalives_idle(&self) -> Duration
fn keepalives_interval(&self) -> Duration
fn keepalives_retries(&self) -> u32
fn statement_timeout(&self) -> Duration