PostgresTimestampOracleConfig

Struct PostgresTimestampOracleConfig 

pub struct PostgresTimestampOracleConfig {
    url: SensitiveUrl,
    metrics: Arc<Metrics>,
    pub dynamic: Arc<DynamicConfig>,
}
Configuration to connect to a Postgres-backed implementation of TimestampOracle.

Fields

url: SensitiveUrlmetrics: Arc<Metrics>dynamic: Arc<DynamicConfig>

Configurations that can be dynamically updated.

Implementations

Source

impl PostgresTimestampOracleConfig

pub(crate) const EXTERNAL_TESTS_POSTGRES_URL: &'static str = "METADATA_BACKEND_URL"

pub fn new(url: &SensitiveUrl, metrics_registry: &MetricsRegistry) -> Self

Returns a new instance of PostgresTimestampOracleConfig with default tuning.

pub fn new_for_test() -> Option<Self>

Returns a new PostgresTimestampOracleConfig for use in unit tests.

By default, postgres oracle tests are no-ops so that cargo test works on new environments without any configuration. To activate the tests for PostgresTimestampOracle set the METADATA_BACKEND_URL environment variable with a valid connection url 1.

pub(crate) fn metrics(&self) -> &Arc<Metrics> ⓘ

Returns the metrics associated with this config.