pub struct TimestampOracleParameters {
pub pg_connection_pool_max_size: Option<usize>,
pub pg_connection_pool_max_wait: Option<Option<Duration>>,
pub pg_connection_pool_ttl: Option<Duration>,
pub pg_connection_pool_ttl_stagger: Option<Duration>,
pub pg_connection_pool_connect_timeout: Option<Duration>,
pub pg_connection_pool_tcp_user_timeout: Option<Duration>,
pub pg_connection_pool_keepalives_idle: Option<Duration>,
pub pg_connection_pool_keepalives_interval: Option<Duration>,
pub pg_connection_pool_keepalives_retries: Option<u32>,
pub pg_statement_timeout: Option<Duration>,
}Expand description
Updates to values in PostgresTimestampOracleConfig.
These reflect updates made to LaunchDarkly.
Parameters can be set (Some) or unset (None). Unset parameters should be
interpreted to mean “use the previous value”.
Fields
pg_connection_pool_max_size: Option<usize>Configures DynamicConfig::pg_connection_pool_max_size.
pg_connection_pool_max_wait: Option<Option<Duration>>Configures DynamicConfig::pg_connection_pool_max_wait.
NOTE: Yes, this is an Option<Option<...>>. Fields in this struct are
all Option to signal the presence or absence of a system var
configuration. A Some(None) value in this field signals the desire to
have no max_wait. This is different from None, which signals that
there is no actively set system var, although this case is not currently
possible with how the code around this works.
pg_connection_pool_ttl: Option<Duration>Configures DynamicConfig::pg_connection_pool_ttl.
pg_connection_pool_ttl_stagger: Option<Duration>Configures DynamicConfig::pg_connection_pool_ttl_stagger.
pg_connection_pool_connect_timeout: Option<Duration>Configures DynamicConfig::pg_connection_pool_connect_timeout.
pg_connection_pool_tcp_user_timeout: Option<Duration>Configures DynamicConfig::pg_connection_pool_tcp_user_timeout.
pg_connection_pool_keepalives_idle: Option<Duration>Configures DynamicConfig::pg_connection_pool_keepalives_idle.
pg_connection_pool_keepalives_interval: Option<Duration>Configures DynamicConfig::pg_connection_pool_keepalives_interval.
pg_connection_pool_keepalives_retries: Option<u32>Configures DynamicConfig::pg_connection_pool_keepalives_retries.
pg_statement_timeout: Option<Duration>Configures DynamicConfig::pg_statement_timeout.
Implementations
Sourceimpl TimestampOracleParameters
impl TimestampOracleParameters
Sourcepub fn update(&mut self, other: TimestampOracleParameters)
pub fn update(&mut self, other: TimestampOracleParameters)
Update the parameter values with the set ones from other.
Sourcepub fn apply(&self, cfg: &PostgresTimestampOracleConfig)
pub fn apply(&self, cfg: &PostgresTimestampOracleConfig)
Applies the parameter values to the given in-memory config object.
Note that these overrides are not all applied atomically: i.e. it’s possible for the timestamp oracle/postgres client to race with this and see some but not all of the parameters applied.